// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: Tree.proto
// Protobuf C++ Version: 6.33.5

#ifndef Tree_2eproto_2epb_2eh
#define Tree_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 6033005
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/map.h"  // IWYU pragma: export
#include "google/protobuf/map_type_handler.h"  // IWYU pragma: export
#include "google/protobuf/map_entry.h"
#include "google/protobuf/map_field.h"
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_Tree_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_Tree_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_Tree_2eproto;
}  // extern "C"
namespace mojo {
namespace spec {
namespace TreeEnsembleModel {
enum INode_MissingType : int;
extern const uint32_t INode_MissingType_internal_data_[];
enum SplitType : int;
extern const uint32_t SplitType_internal_data_[];
class INode;
struct INodeDefaultTypeInternal;
extern INodeDefaultTypeInternal _INode_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull INode_class_data_;
class LNode;
struct LNodeDefaultTypeInternal;
extern LNodeDefaultTypeInternal _LNode_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull LNode_class_data_;
class LinearBooster;
struct LinearBoosterDefaultTypeInternal;
extern LinearBoosterDefaultTypeInternal _LinearBooster_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull LinearBooster_class_data_;
class Model;
struct ModelDefaultTypeInternal;
extern ModelDefaultTypeInternal _Model_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull Model_class_data_;
class Model_FeatureMapEntry_DoNotUse;
struct Model_FeatureMapEntry_DoNotUseDefaultTypeInternal;
extern Model_FeatureMapEntry_DoNotUseDefaultTypeInternal _Model_FeatureMapEntry_DoNotUse_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull Model_FeatureMapEntry_DoNotUse_class_data_;
class Node;
struct NodeDefaultTypeInternal;
extern NodeDefaultTypeInternal _Node_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull Node_class_data_;
class Tree;
struct TreeDefaultTypeInternal;
extern TreeDefaultTypeInternal _Tree_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull Tree_class_data_;
class TreeBooster;
struct TreeBoosterDefaultTypeInternal;
extern TreeBoosterDefaultTypeInternal _TreeBooster_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull TreeBooster_class_data_;
class Weight;
struct WeightDefaultTypeInternal;
extern WeightDefaultTypeInternal _Weight_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull Weight_class_data_;
}  // namespace TreeEnsembleModel
}  // namespace spec
}  // namespace mojo
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::mojo::spec::TreeEnsembleModel::INode_MissingType_internal_data_>
    internal::EnumTraitsImpl::value<::mojo::spec::TreeEnsembleModel::INode_MissingType>;
template <>
internal::EnumTraitsT<::mojo::spec::TreeEnsembleModel::SplitType_internal_data_>
    internal::EnumTraitsImpl::value<::mojo::spec::TreeEnsembleModel::SplitType>;
}  // namespace protobuf
}  // namespace google

namespace mojo {
namespace spec {
namespace TreeEnsembleModel {
enum INode_MissingType : int {
  INode_MissingType_UNSPECIFIED = 0,
  INode_MissingType_TREAT_NAN_AS_ZERO = 1,
  INode_MissingType_TREAT_ZERO_AS_NAN = 2,
  INode_MissingType_NO_CHANGE = 3,
  INode_MissingType_INode_MissingType_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  INode_MissingType_INode_MissingType_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t INode_MissingType_internal_data_[];
inline constexpr INode_MissingType INode_MissingType_MissingType_MIN =
    static_cast<INode_MissingType>(0);
inline constexpr INode_MissingType INode_MissingType_MissingType_MAX =
    static_cast<INode_MissingType>(3);
inline bool INode_MissingType_IsValid(int value) {
  return 0 <= value && value <= 3;
}
inline constexpr int INode_MissingType_MissingType_ARRAYSIZE = 3 + 1;
const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL INode_MissingType_descriptor();
template <typename T>
const ::std::string& INode_MissingType_Name(T value) {
  static_assert(::std::is_same<T, INode_MissingType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to MissingType_Name().");
  return INode_MissingType_Name(static_cast<INode_MissingType>(value));
}
template <>
inline const ::std::string& INode_MissingType_Name(INode_MissingType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<INode_MissingType_descriptor, 0, 3>(
      static_cast<int>(value));
}
inline bool INode_MissingType_Parse(
    ::absl::string_view name, INode_MissingType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<INode_MissingType>(INode_MissingType_descriptor(), name,
                                           value);
}
enum SplitType : int {
  UNKNOWN_SPLIT_TYPE = 0,
  LT = 1,
  GT = 2,
  LE = 3,
  GE = 4,
  EQ = 5,
  SplitType_INT_MIN_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::min(),
  SplitType_INT_MAX_SENTINEL_DO_NOT_USE_ =
      ::std::numeric_limits<::int32_t>::max(),
};

extern const uint32_t SplitType_internal_data_[];
inline constexpr SplitType SplitType_MIN =
    static_cast<SplitType>(0);
inline constexpr SplitType SplitType_MAX =
    static_cast<SplitType>(5);
inline bool SplitType_IsValid(int value) {
  return 0 <= value && value <= 5;
}
inline constexpr int SplitType_ARRAYSIZE = 5 + 1;
const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL SplitType_descriptor();
template <typename T>
const ::std::string& SplitType_Name(T value) {
  static_assert(::std::is_same<T, SplitType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to SplitType_Name().");
  return SplitType_Name(static_cast<SplitType>(value));
}
template <>
inline const ::std::string& SplitType_Name(SplitType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<SplitType_descriptor, 0, 5>(
      static_cast<int>(value));
}
inline bool SplitType_Parse(
    ::absl::string_view name, SplitType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<SplitType>(SplitType_descriptor(), name,
                                           value);
}

// ===================================================================


// -------------------------------------------------------------------

class Weight final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.Weight) */ {
 public:
  inline Weight() : Weight(nullptr) {}
  ~Weight() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Weight* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Weight));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Weight(::google::protobuf::internal::ConstantInitialized);

  inline Weight(const Weight& from) : Weight(nullptr, from) {}
  inline Weight(Weight&& from) noexcept
      : Weight(nullptr, ::std::move(from)) {}
  inline Weight& operator=(const Weight& from) {
    CopyFrom(from);
    return *this;
  }
  inline Weight& operator=(Weight&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Weight& default_instance() {
    return *reinterpret_cast<const Weight*>(
        &_Weight_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 4;
  friend void swap(Weight& a, Weight& b) { a.Swap(&b); }
  inline void Swap(Weight* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Weight* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Weight* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Weight>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Weight& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Weight& from) { Weight::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Weight* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.Weight"; }

  explicit Weight(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Weight(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Weight& from);
  Weight(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Weight&& from) noexcept
      : Weight(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kWeightFieldNumber = 1,
  };
  // repeated double weight = 1;
  int weight_size() const;
  private:
  int _internal_weight_size() const;

  public:
  void clear_weight() ;
  double weight(int index) const;
  void set_weight(int index, double value);
  void add_weight(double value);
  const ::google::protobuf::RepeatedField<double>& weight() const;
  ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL mutable_weight();

  private:
  const ::google::protobuf::RepeatedField<double>& _internal_weight() const;
  ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL _internal_mutable_weight();

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.Weight)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 1,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Weight& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedField<double> weight_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull Weight_class_data_;
// -------------------------------------------------------------------

class Model_FeatureMapEntry_DoNotUse final
    : public ::google::protobuf::internal::MapEntry<::int32_t, ::std::string,
                             ::google::protobuf::internal::WireFormatLite::TYPE_INT32,
                             ::google::protobuf::internal::WireFormatLite::TYPE_STRING> {
 public:
  using SuperType =
      ::google::protobuf::internal::MapEntry<::int32_t, ::std::string,
                      ::google::protobuf::internal::WireFormatLite::TYPE_INT32,
                      ::google::protobuf::internal::WireFormatLite::TYPE_STRING>;
  Model_FeatureMapEntry_DoNotUse();
  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Model_FeatureMapEntry_DoNotUse(::google::protobuf::internal::ConstantInitialized);
  explicit Model_FeatureMapEntry_DoNotUse(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr const void* PROTOBUF_NONNULL internal_default_instance() {
    return &_Model_FeatureMapEntry_DoNotUse_default_instance_;
  }


  static constexpr auto InternalGenerateClassData_();

 private:
  friend class ::google::protobuf::MessageLite;
  friend struct ::TableStruct_Tree_2eproto;

  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 2,
                                   0, 63,
                                   2>
      _table_;

  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();
};
extern const ::google::protobuf::internal::ClassDataFull Model_FeatureMapEntry_DoNotUse_class_data_;
// -------------------------------------------------------------------

class LNode final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.LNode) */ {
 public:
  inline LNode() : LNode(nullptr) {}
  ~LNode() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(LNode* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(LNode));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR LNode(::google::protobuf::internal::ConstantInitialized);

  inline LNode(const LNode& from) : LNode(nullptr, from) {}
  inline LNode(LNode&& from) noexcept
      : LNode(nullptr, ::std::move(from)) {}
  inline LNode& operator=(const LNode& from) {
    CopyFrom(from);
    return *this;
  }
  inline LNode& operator=(LNode&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const LNode& default_instance() {
    return *reinterpret_cast<const LNode*>(
        &_LNode_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(LNode& a, LNode& b) { a.Swap(&b); }
  inline void Swap(LNode* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(LNode* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  LNode* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<LNode>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const LNode& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const LNode& from) { LNode::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(LNode* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.LNode"; }

  explicit LNode(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  LNode(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const LNode& from);
  LNode(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, LNode&& from) noexcept
      : LNode(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kValueFieldNumber = 1,
  };
  // double value = 1;
  void clear_value() ;
  double value() const;
  void set_value(double value);

  private:
  double _internal_value() const;
  void _internal_set_value(double value);

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.LNode)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<0, 1,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const LNode& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    double value_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull LNode_class_data_;
// -------------------------------------------------------------------

class INode final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.INode) */ {
 public:
  inline INode() : INode(nullptr) {}
  ~INode() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(INode* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(INode));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR INode(::google::protobuf::internal::ConstantInitialized);

  inline INode(const INode& from) : INode(nullptr, from) {}
  inline INode(INode&& from) noexcept
      : INode(nullptr, ::std::move(from)) {}
  inline INode& operator=(const INode& from) {
    CopyFrom(from);
    return *this;
  }
  inline INode& operator=(INode&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const INode& default_instance() {
    return *reinterpret_cast<const INode*>(
        &_INode_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(INode& a, INode& b) { a.Swap(&b); }
  inline void Swap(INode* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(INode* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  INode* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<INode>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const INode& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const INode& from) { INode::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(INode* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.INode"; }

  explicit INode(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  INode(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const INode& from);
  INode(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, INode&& from) noexcept
      : INode(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using MissingType = INode_MissingType;
  static constexpr MissingType UNSPECIFIED = INode_MissingType_UNSPECIFIED;
  static constexpr MissingType TREAT_NAN_AS_ZERO = INode_MissingType_TREAT_NAN_AS_ZERO;
  static constexpr MissingType TREAT_ZERO_AS_NAN = INode_MissingType_TREAT_ZERO_AS_NAN;
  static constexpr MissingType NO_CHANGE = INode_MissingType_NO_CHANGE;
  static inline bool MissingType_IsValid(int value) {
    return INode_MissingType_IsValid(value);
  }
  static constexpr MissingType MissingType_MIN = INode_MissingType_MissingType_MIN;
  static constexpr MissingType MissingType_MAX = INode_MissingType_MissingType_MAX;
  static constexpr int MissingType_ARRAYSIZE = INode_MissingType_MissingType_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL MissingType_descriptor() {
    return INode_MissingType_descriptor();
  }
  template <typename T>
  static inline const ::std::string& MissingType_Name(T value) {
    return INode_MissingType_Name(value);
  }
  static inline bool MissingType_Parse(
      ::absl::string_view name, MissingType* PROTOBUF_NONNULL value) {
    return INode_MissingType_Parse(name, value);
  }

  // accessors -------------------------------------------------------
  enum : int {
    kSplitValueFieldNumber = 2,
    kSplitFeatureFieldNumber = 1,
    kTypeFieldNumber = 3,
    kYesFieldNumber = 4,
    kNoFieldNumber = 5,
    kMissingFieldNumber = 6,
    kMissingTypeFieldNumber = 7,
  };
  // double split_value = 2;
  void clear_split_value() ;
  double split_value() const;
  void set_split_value(double value);

  private:
  double _internal_split_value() const;
  void _internal_set_split_value(double value);

  public:
  // int32 split_feature = 1;
  void clear_split_feature() ;
  ::int32_t split_feature() const;
  void set_split_feature(::int32_t value);

  private:
  ::int32_t _internal_split_feature() const;
  void _internal_set_split_feature(::int32_t value);

  public:
  // .mojo.spec.TreeEnsembleModel.SplitType type = 3;
  void clear_type() ;
  ::mojo::spec::TreeEnsembleModel::SplitType type() const;
  void set_type(::mojo::spec::TreeEnsembleModel::SplitType value);

  private:
  ::mojo::spec::TreeEnsembleModel::SplitType _internal_type() const;
  void _internal_set_type(::mojo::spec::TreeEnsembleModel::SplitType value);

  public:
  // int32 yes = 4;
  void clear_yes() ;
  ::int32_t yes() const;
  void set_yes(::int32_t value);

  private:
  ::int32_t _internal_yes() const;
  void _internal_set_yes(::int32_t value);

  public:
  // int32 no = 5;
  void clear_no() ;
  ::int32_t no() const;
  void set_no(::int32_t value);

  private:
  ::int32_t _internal_no() const;
  void _internal_set_no(::int32_t value);

  public:
  // int32 missing = 6;
  void clear_missing() ;
  ::int32_t missing() const;
  void set_missing(::int32_t value);

  private:
  ::int32_t _internal_missing() const;
  void _internal_set_missing(::int32_t value);

  public:
  // .mojo.spec.TreeEnsembleModel.INode.MissingType missing_type = 7;
  void clear_missing_type() ;
  ::mojo::spec::TreeEnsembleModel::INode_MissingType missing_type() const;
  void set_missing_type(::mojo::spec::TreeEnsembleModel::INode_MissingType value);

  private:
  ::mojo::spec::TreeEnsembleModel::INode_MissingType _internal_missing_type() const;
  void _internal_set_missing_type(::mojo::spec::TreeEnsembleModel::INode_MissingType value);

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.INode)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<3, 7,
                                   0, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const INode& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    double split_value_;
    ::int32_t split_feature_;
    int type_;
    ::int32_t yes_;
    ::int32_t no_;
    ::int32_t missing_;
    int missing_type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull INode_class_data_;
// -------------------------------------------------------------------

class Node final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.Node) */ {
 public:
  inline Node() : Node(nullptr) {}
  ~Node() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Node* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Node));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Node(::google::protobuf::internal::ConstantInitialized);

  inline Node(const Node& from) : Node(nullptr, from) {}
  inline Node(Node&& from) noexcept
      : Node(nullptr, ::std::move(from)) {}
  inline Node& operator=(const Node& from) {
    CopyFrom(from);
    return *this;
  }
  inline Node& operator=(Node&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Node& default_instance() {
    return *reinterpret_cast<const Node*>(
        &_Node_default_instance_);
  }
  enum NodeTypeCase {
    kInode = 2,
    kLnode = 3,
    NODE_TYPE_NOT_SET = 0,
  };
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(Node& a, Node& b) { a.Swap(&b); }
  inline void Swap(Node* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Node* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Node* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Node>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Node& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Node& from) { Node::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Node* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.Node"; }

  explicit Node(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Node(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Node& from);
  Node(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Node&& from) noexcept
      : Node(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kDataCountFieldNumber = 4,
    kIdFieldNumber = 1,
    kInodeFieldNumber = 2,
    kLnodeFieldNumber = 3,
  };
  // double data_count = 4;
  void clear_data_count() ;
  double data_count() const;
  void set_data_count(double value);

  private:
  double _internal_data_count() const;
  void _internal_set_data_count(double value);

  public:
  // int32 id = 1;
  void clear_id() ;
  ::int32_t id() const;
  void set_id(::int32_t value);

  private:
  ::int32_t _internal_id() const;
  void _internal_set_id(::int32_t value);

  public:
  // .mojo.spec.TreeEnsembleModel.INode inode = 2;
  bool has_inode() const;
  private:
  bool _internal_has_inode() const;

  public:
  void clear_inode() ;
  const ::mojo::spec::TreeEnsembleModel::INode& inode() const;
  [[nodiscard]] ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE release_inode();
  ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NONNULL mutable_inode();
  void set_allocated_inode(::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_inode(::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE value);
  ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE unsafe_arena_release_inode();

  private:
  const ::mojo::spec::TreeEnsembleModel::INode& _internal_inode() const;
  ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NONNULL _internal_mutable_inode();

  public:
  // .mojo.spec.TreeEnsembleModel.LNode lnode = 3;
  bool has_lnode() const;
  private:
  bool _internal_has_lnode() const;

  public:
  void clear_lnode() ;
  const ::mojo::spec::TreeEnsembleModel::LNode& lnode() const;
  [[nodiscard]] ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE release_lnode();
  ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NONNULL mutable_lnode();
  void set_allocated_lnode(::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_lnode(::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE value);
  ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE unsafe_arena_release_lnode();

  private:
  const ::mojo::spec::TreeEnsembleModel::LNode& _internal_lnode() const;
  ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NONNULL _internal_mutable_lnode();

  public:
  void clear_node_type();
  NodeTypeCase node_type_case() const;
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.Node)
 private:
  class _Internal;
  void set_has_inode();
  void set_has_lnode();
  inline bool has_node_type() const;
  inline void clear_has_node_type();
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 4,
                                   2, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Node& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    double data_count_;
    ::int32_t id_;
    union NodeTypeUnion {
      constexpr NodeTypeUnion() : _constinit_{} {}
      ::google::protobuf::internal::ConstantInitialized _constinit_;
      ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE inode_;
      ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE lnode_;
    } node_type_;
    ::uint32_t _oneof_case_[1];
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull Node_class_data_;
// -------------------------------------------------------------------

class LinearBooster final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.LinearBooster) */ {
 public:
  inline LinearBooster() : LinearBooster(nullptr) {}
  ~LinearBooster() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(LinearBooster* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(LinearBooster));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR LinearBooster(::google::protobuf::internal::ConstantInitialized);

  inline LinearBooster(const LinearBooster& from) : LinearBooster(nullptr, from) {}
  inline LinearBooster(LinearBooster&& from) noexcept
      : LinearBooster(nullptr, ::std::move(from)) {}
  inline LinearBooster& operator=(const LinearBooster& from) {
    CopyFrom(from);
    return *this;
  }
  inline LinearBooster& operator=(LinearBooster&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const LinearBooster& default_instance() {
    return *reinterpret_cast<const LinearBooster*>(
        &_LinearBooster_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 6;
  friend void swap(LinearBooster& a, LinearBooster& b) { a.Swap(&b); }
  inline void Swap(LinearBooster* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(LinearBooster* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  LinearBooster* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<LinearBooster>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const LinearBooster& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const LinearBooster& from) { LinearBooster::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(LinearBooster* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.LinearBooster"; }

  explicit LinearBooster(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  LinearBooster(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const LinearBooster& from);
  LinearBooster(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, LinearBooster&& from) noexcept
      : LinearBooster(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kWeightsFieldNumber = 1,
    kBiasFieldNumber = 2,
  };
  // repeated .mojo.spec.TreeEnsembleModel.Weight weights = 1;
  int weights_size() const;
  private:
  int _internal_weights_size() const;

  public:
  void clear_weights() ;
  ::mojo::spec::TreeEnsembleModel::Weight* PROTOBUF_NONNULL mutable_weights(int index);
  ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>* PROTOBUF_NONNULL mutable_weights();

  private:
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>& _internal_weights() const;
  ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>* PROTOBUF_NONNULL _internal_mutable_weights();
  public:
  const ::mojo::spec::TreeEnsembleModel::Weight& weights(int index) const;
  ::mojo::spec::TreeEnsembleModel::Weight* PROTOBUF_NONNULL add_weights();
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>& weights() const;
  // repeated double bias = 2;
  int bias_size() const;
  private:
  int _internal_bias_size() const;

  public:
  void clear_bias() ;
  double bias(int index) const;
  void set_bias(int index, double value);
  void add_bias(double value);
  const ::google::protobuf::RepeatedField<double>& bias() const;
  ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL mutable_bias();

  private:
  const ::google::protobuf::RepeatedField<double>& _internal_bias() const;
  ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL _internal_mutable_bias();

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.LinearBooster)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 2,
                                   1, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const LinearBooster& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::mojo::spec::TreeEnsembleModel::Weight > weights_;
    ::google::protobuf::RepeatedField<double> bias_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull LinearBooster_class_data_;
// -------------------------------------------------------------------

class Tree final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.Tree) */ {
 public:
  inline Tree() : Tree(nullptr) {}
  ~Tree() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Tree* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Tree));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Tree(::google::protobuf::internal::ConstantInitialized);

  inline Tree(const Tree& from) : Tree(nullptr, from) {}
  inline Tree(Tree&& from) noexcept
      : Tree(nullptr, ::std::move(from)) {}
  inline Tree& operator=(const Tree& from) {
    CopyFrom(from);
    return *this;
  }
  inline Tree& operator=(Tree&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Tree& default_instance() {
    return *reinterpret_cast<const Tree*>(
        &_Tree_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 3;
  friend void swap(Tree& a, Tree& b) { a.Swap(&b); }
  inline void Swap(Tree* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Tree* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Tree* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Tree>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Tree& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Tree& from) { Tree::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Tree* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.Tree"; }

  explicit Tree(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Tree(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Tree& from);
  Tree(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Tree&& from) noexcept
      : Tree(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kNodesFieldNumber = 1,
    kExpectedValueFieldNumber = 2,
  };
  // repeated .mojo.spec.TreeEnsembleModel.Node nodes = 1;
  int nodes_size() const;
  private:
  int _internal_nodes_size() const;

  public:
  void clear_nodes() ;
  ::mojo::spec::TreeEnsembleModel::Node* PROTOBUF_NONNULL mutable_nodes(int index);
  ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>* PROTOBUF_NONNULL mutable_nodes();

  private:
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>& _internal_nodes() const;
  ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>* PROTOBUF_NONNULL _internal_mutable_nodes();
  public:
  const ::mojo::spec::TreeEnsembleModel::Node& nodes(int index) const;
  ::mojo::spec::TreeEnsembleModel::Node* PROTOBUF_NONNULL add_nodes();
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>& nodes() const;
  // double expected_value = 2;
  void clear_expected_value() ;
  double expected_value() const;
  void set_expected_value(double value);

  private:
  double _internal_expected_value() const;
  void _internal_set_expected_value(double value);

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.Tree)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 2,
                                   1, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Tree& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::mojo::spec::TreeEnsembleModel::Node > nodes_;
    double expected_value_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull Tree_class_data_;
// -------------------------------------------------------------------

class TreeBooster final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.TreeBooster) */ {
 public:
  inline TreeBooster() : TreeBooster(nullptr) {}
  ~TreeBooster() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(TreeBooster* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(TreeBooster));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR TreeBooster(::google::protobuf::internal::ConstantInitialized);

  inline TreeBooster(const TreeBooster& from) : TreeBooster(nullptr, from) {}
  inline TreeBooster(TreeBooster&& from) noexcept
      : TreeBooster(nullptr, ::std::move(from)) {}
  inline TreeBooster& operator=(const TreeBooster& from) {
    CopyFrom(from);
    return *this;
  }
  inline TreeBooster& operator=(TreeBooster&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const TreeBooster& default_instance() {
    return *reinterpret_cast<const TreeBooster*>(
        &_TreeBooster_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 5;
  friend void swap(TreeBooster& a, TreeBooster& b) { a.Swap(&b); }
  inline void Swap(TreeBooster* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(TreeBooster* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  TreeBooster* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<TreeBooster>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const TreeBooster& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const TreeBooster& from) { TreeBooster::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(TreeBooster* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.TreeBooster"; }

  explicit TreeBooster(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  TreeBooster(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const TreeBooster& from);
  TreeBooster(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, TreeBooster&& from) noexcept
      : TreeBooster(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kTreesFieldNumber = 1,
    kTreeInfoFieldNumber = 2,
  };
  // repeated .mojo.spec.TreeEnsembleModel.Tree trees = 1;
  int trees_size() const;
  private:
  int _internal_trees_size() const;

  public:
  void clear_trees() ;
  ::mojo::spec::TreeEnsembleModel::Tree* PROTOBUF_NONNULL mutable_trees(int index);
  ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>* PROTOBUF_NONNULL mutable_trees();

  private:
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>& _internal_trees() const;
  ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>* PROTOBUF_NONNULL _internal_mutable_trees();
  public:
  const ::mojo::spec::TreeEnsembleModel::Tree& trees(int index) const;
  ::mojo::spec::TreeEnsembleModel::Tree* PROTOBUF_NONNULL add_trees();
  const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>& trees() const;
  // repeated int32 tree_info = 2;
  int tree_info_size() const;
  private:
  int _internal_tree_info_size() const;

  public:
  void clear_tree_info() ;
  ::int32_t tree_info(int index) const;
  void set_tree_info(int index, ::int32_t value);
  void add_tree_info(::int32_t value);
  const ::google::protobuf::RepeatedField<::int32_t>& tree_info() const;
  ::google::protobuf::RepeatedField<::int32_t>* PROTOBUF_NONNULL mutable_tree_info();

  private:
  const ::google::protobuf::RepeatedField<::int32_t>& _internal_tree_info() const;
  ::google::protobuf::RepeatedField<::int32_t>* PROTOBUF_NONNULL _internal_mutable_tree_info();

  public:
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.TreeBooster)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<1, 2,
                                   1, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const TreeBooster& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::mojo::spec::TreeEnsembleModel::Tree > trees_;
    ::google::protobuf::RepeatedField<::int32_t> tree_info_;
    ::google::protobuf::internal::CachedSize _tree_info_cached_byte_size_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull TreeBooster_class_data_;
// -------------------------------------------------------------------

class Model final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:mojo.spec.TreeEnsembleModel.Model) */ {
 public:
  inline Model() : Model(nullptr) {}
  ~Model() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(Model* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(Model));
  }
#endif

  template <typename = void>
  explicit PROTOBUF_CONSTEXPR Model(::google::protobuf::internal::ConstantInitialized);

  inline Model(const Model& from) : Model(nullptr, from) {}
  inline Model(Model&& from) noexcept
      : Model(nullptr, ::std::move(from)) {}
  inline Model& operator=(const Model& from) {
    CopyFrom(from);
    return *this;
  }
  inline Model& operator=(Model&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL mutable_unknown_fields()
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Model& default_instance() {
    return *reinterpret_cast<const Model*>(
        &_Model_default_instance_);
  }
  enum BoosterCase {
    kTree = 4,
    kLinear = 5,
    BOOSTER_NOT_SET = 0,
  };
  static constexpr int kIndexInFileMessages = 8;
  friend void swap(Model& a, Model& b) { a.Swap(&b); }
  inline void Swap(Model* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Model* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  Model* PROTOBUF_NONNULL New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<Model>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const Model& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const Model& from) { Model::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  ::size_t ByteSizeLong() const final;
  ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  int GetCachedSize() const { return _impl_._cached_size_.Get(); }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(Model* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "mojo.spec.TreeEnsembleModel.Model"; }

  explicit Model(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  Model(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Model& from);
  Model(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, Model&& from) noexcept
      : Model(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kVersionFieldNumber = 1,
    kBaseMarginFieldNumber = 3,
    kNumOutputGroupFieldNumber = 2,
    kFeatureMapFieldNumber = 6,
    kTreeFieldNumber = 4,
    kLinearFieldNumber = 5,
  };
  // string version = 1;
  void clear_version() ;
  const ::std::string& version() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_version(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_version();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_version();
  void set_allocated_version(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_version() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_version(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_version();

  public:
  // double base_margin = 3;
  void clear_base_margin() ;
  double base_margin() const;
  void set_base_margin(double value);

  private:
  double _internal_base_margin() const;
  void _internal_set_base_margin(double value);

  public:
  // int32 num_output_group = 2;
  void clear_num_output_group() ;
  ::int32_t num_output_group() const;
  void set_num_output_group(::int32_t value);

  private:
  ::int32_t _internal_num_output_group() const;
  void _internal_set_num_output_group(::int32_t value);

  public:
  // map<int32, string> feature_map = 6;
  int feature_map_size() const;
  private:
  int _internal_feature_map_size() const;

  public:
  void clear_feature_map() ;
  const ::google::protobuf::Map<::int32_t, ::std::string>& feature_map() const;
  ::google::protobuf::Map<::int32_t, ::std::string>* PROTOBUF_NONNULL mutable_feature_map();

  private:
  const ::google::protobuf::Map<::int32_t, ::std::string>& _internal_feature_map() const;
  ::google::protobuf::Map<::int32_t, ::std::string>* PROTOBUF_NONNULL _internal_mutable_feature_map();

  public:
  // .mojo.spec.TreeEnsembleModel.TreeBooster tree = 4;
  bool has_tree() const;
  private:
  bool _internal_has_tree() const;

  public:
  void clear_tree() ;
  const ::mojo::spec::TreeEnsembleModel::TreeBooster& tree() const;
  [[nodiscard]] ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE release_tree();
  ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NONNULL mutable_tree();
  void set_allocated_tree(::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_tree(::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE value);
  ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE unsafe_arena_release_tree();

  private:
  const ::mojo::spec::TreeEnsembleModel::TreeBooster& _internal_tree() const;
  ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NONNULL _internal_mutable_tree();

  public:
  // .mojo.spec.TreeEnsembleModel.LinearBooster linear = 5;
  bool has_linear() const;
  private:
  bool _internal_has_linear() const;

  public:
  void clear_linear() ;
  const ::mojo::spec::TreeEnsembleModel::LinearBooster& linear() const;
  [[nodiscard]] ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE release_linear();
  ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NONNULL mutable_linear();
  void set_allocated_linear(::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_linear(::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE value);
  ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE unsafe_arena_release_linear();

  private:
  const ::mojo::spec::TreeEnsembleModel::LinearBooster& _internal_linear() const;
  ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NONNULL _internal_mutable_linear();

  public:
  void clear_booster();
  BoosterCase booster_case() const;
  // @@protoc_insertion_point(class_scope:mojo.spec.TreeEnsembleModel.Model)
 private:
  class _Internal;
  void set_has_tree();
  void set_has_linear();
  inline bool has_booster() const;
  inline void clear_has_booster();
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<2, 6,
                                   3, 60,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const Model& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr version_;
    double base_margin_;
    ::int32_t num_output_group_;
    ::google::protobuf::internal::MapField<Model_FeatureMapEntry_DoNotUse, ::int32_t, ::std::string,
                      ::google::protobuf::internal::WireFormatLite::TYPE_INT32,
                      ::google::protobuf::internal::WireFormatLite::TYPE_STRING>
        feature_map_;
    union BoosterUnion {
      constexpr BoosterUnion() : _constinit_{} {}
      ::google::protobuf::internal::ConstantInitialized _constinit_;
      ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE tree_;
      ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE linear_;
    } booster_;
    ::uint32_t _oneof_case_[1];
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_Tree_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull Model_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// INode

// int32 split_feature = 1;
inline void INode::clear_split_feature() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.split_feature_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
inline ::int32_t INode::split_feature() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.split_feature)
  return _internal_split_feature();
}
inline void INode::set_split_feature(::int32_t value) {
  _internal_set_split_feature(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.split_feature)
}
inline ::int32_t INode::_internal_split_feature() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.split_feature_;
}
inline void INode::_internal_set_split_feature(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.split_feature_ = value;
}

// double split_value = 2;
inline void INode::clear_split_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.split_value_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline double INode::split_value() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.split_value)
  return _internal_split_value();
}
inline void INode::set_split_value(double value) {
  _internal_set_split_value(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.split_value)
}
inline double INode::_internal_split_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.split_value_;
}
inline void INode::_internal_set_split_value(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.split_value_ = value;
}

// .mojo.spec.TreeEnsembleModel.SplitType type = 3;
inline void INode::clear_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
inline ::mojo::spec::TreeEnsembleModel::SplitType INode::type() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.type)
  return _internal_type();
}
inline void INode::set_type(::mojo::spec::TreeEnsembleModel::SplitType value) {
  _internal_set_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.type)
}
inline ::mojo::spec::TreeEnsembleModel::SplitType INode::_internal_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::mojo::spec::TreeEnsembleModel::SplitType>(_impl_.type_);
}
inline void INode::_internal_set_type(::mojo::spec::TreeEnsembleModel::SplitType value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.type_ = value;
}

// int32 yes = 4;
inline void INode::clear_yes() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.yes_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000008U);
}
inline ::int32_t INode::yes() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.yes)
  return _internal_yes();
}
inline void INode::set_yes(::int32_t value) {
  _internal_set_yes(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.yes)
}
inline ::int32_t INode::_internal_yes() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.yes_;
}
inline void INode::_internal_set_yes(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.yes_ = value;
}

// int32 no = 5;
inline void INode::clear_no() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.no_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000010U);
}
inline ::int32_t INode::no() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.no)
  return _internal_no();
}
inline void INode::set_no(::int32_t value) {
  _internal_set_no(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.no)
}
inline ::int32_t INode::_internal_no() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.no_;
}
inline void INode::_internal_set_no(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.no_ = value;
}

// int32 missing = 6;
inline void INode::clear_missing() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.missing_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000020U);
}
inline ::int32_t INode::missing() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.missing)
  return _internal_missing();
}
inline void INode::set_missing(::int32_t value) {
  _internal_set_missing(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.missing)
}
inline ::int32_t INode::_internal_missing() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.missing_;
}
inline void INode::_internal_set_missing(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.missing_ = value;
}

// .mojo.spec.TreeEnsembleModel.INode.MissingType missing_type = 7;
inline void INode::clear_missing_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.missing_type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000040U);
}
inline ::mojo::spec::TreeEnsembleModel::INode_MissingType INode::missing_type() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.INode.missing_type)
  return _internal_missing_type();
}
inline void INode::set_missing_type(::mojo::spec::TreeEnsembleModel::INode_MissingType value) {
  _internal_set_missing_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.INode.missing_type)
}
inline ::mojo::spec::TreeEnsembleModel::INode_MissingType INode::_internal_missing_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return static_cast<::mojo::spec::TreeEnsembleModel::INode_MissingType>(_impl_.missing_type_);
}
inline void INode::_internal_set_missing_type(::mojo::spec::TreeEnsembleModel::INode_MissingType value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.missing_type_ = value;
}

// -------------------------------------------------------------------

// LNode

// double value = 1;
inline void LNode::clear_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.value_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline double LNode::value() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.LNode.value)
  return _internal_value();
}
inline void LNode::set_value(double value) {
  _internal_set_value(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.LNode.value)
}
inline double LNode::_internal_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.value_;
}
inline void LNode::_internal_set_value(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.value_ = value;
}

// -------------------------------------------------------------------

// Node

// int32 id = 1;
inline void Node::clear_id() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
inline ::int32_t Node::id() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Node.id)
  return _internal_id();
}
inline void Node::set_id(::int32_t value) {
  _internal_set_id(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Node.id)
}
inline ::int32_t Node::_internal_id() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.id_;
}
inline void Node::_internal_set_id(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.id_ = value;
}

// .mojo.spec.TreeEnsembleModel.INode inode = 2;
inline bool Node::has_inode() const {
  return node_type_case() == kInode;
}
inline bool Node::_internal_has_inode() const {
  return node_type_case() == kInode;
}
inline void Node::set_has_inode() {
  _impl_._oneof_case_[0] = kInode;
}
inline void Node::clear_inode() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (node_type_case() == kInode) {
    if (GetArena() == nullptr) {
      delete _impl_.node_type_.inode_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.node_type_.inode_);
    }
    clear_has_node_type();
  }
}
inline ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE Node::release_inode() {
  // @@protoc_insertion_point(field_release:mojo.spec.TreeEnsembleModel.Node.inode)
  if (node_type_case() == kInode) {
    clear_has_node_type();
    auto* temp = _impl_.node_type_.inode_;
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.node_type_.inode_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::mojo::spec::TreeEnsembleModel::INode& Node::_internal_inode() const {
  return node_type_case() == kInode ? static_cast<const ::mojo::spec::TreeEnsembleModel::INode&>(*_impl_.node_type_.inode_)
                     : reinterpret_cast<const ::mojo::spec::TreeEnsembleModel::INode&>(::mojo::spec::TreeEnsembleModel::_INode_default_instance_);
}
inline const ::mojo::spec::TreeEnsembleModel::INode& Node::inode() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Node.inode)
  return _internal_inode();
}
inline ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE Node::unsafe_arena_release_inode() {
  // @@protoc_insertion_point(field_unsafe_arena_release:mojo.spec.TreeEnsembleModel.Node.inode)
  if (node_type_case() == kInode) {
    clear_has_node_type();
    auto* temp = _impl_.node_type_.inode_;
    _impl_.node_type_.inode_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Node::unsafe_arena_set_allocated_inode(
    ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_node_type();
  if (value) {
    set_has_inode();
    _impl_.node_type_.inode_ = value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:mojo.spec.TreeEnsembleModel.Node.inode)
}
inline ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NONNULL Node::_internal_mutable_inode() {
  if (node_type_case() != kInode) {
    clear_node_type();
    set_has_inode();
    _impl_.node_type_.inode_ = 
        ::google::protobuf::Message::DefaultConstruct<::mojo::spec::TreeEnsembleModel::INode>(GetArena());
  }
  return _impl_.node_type_.inode_;
}
inline ::mojo::spec::TreeEnsembleModel::INode* PROTOBUF_NONNULL Node::mutable_inode()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::mojo::spec::TreeEnsembleModel::INode* _msg = _internal_mutable_inode();
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.Node.inode)
  return _msg;
}

// .mojo.spec.TreeEnsembleModel.LNode lnode = 3;
inline bool Node::has_lnode() const {
  return node_type_case() == kLnode;
}
inline bool Node::_internal_has_lnode() const {
  return node_type_case() == kLnode;
}
inline void Node::set_has_lnode() {
  _impl_._oneof_case_[0] = kLnode;
}
inline void Node::clear_lnode() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (node_type_case() == kLnode) {
    if (GetArena() == nullptr) {
      delete _impl_.node_type_.lnode_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.node_type_.lnode_);
    }
    clear_has_node_type();
  }
}
inline ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE Node::release_lnode() {
  // @@protoc_insertion_point(field_release:mojo.spec.TreeEnsembleModel.Node.lnode)
  if (node_type_case() == kLnode) {
    clear_has_node_type();
    auto* temp = _impl_.node_type_.lnode_;
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.node_type_.lnode_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::mojo::spec::TreeEnsembleModel::LNode& Node::_internal_lnode() const {
  return node_type_case() == kLnode ? static_cast<const ::mojo::spec::TreeEnsembleModel::LNode&>(*_impl_.node_type_.lnode_)
                     : reinterpret_cast<const ::mojo::spec::TreeEnsembleModel::LNode&>(::mojo::spec::TreeEnsembleModel::_LNode_default_instance_);
}
inline const ::mojo::spec::TreeEnsembleModel::LNode& Node::lnode() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Node.lnode)
  return _internal_lnode();
}
inline ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE Node::unsafe_arena_release_lnode() {
  // @@protoc_insertion_point(field_unsafe_arena_release:mojo.spec.TreeEnsembleModel.Node.lnode)
  if (node_type_case() == kLnode) {
    clear_has_node_type();
    auto* temp = _impl_.node_type_.lnode_;
    _impl_.node_type_.lnode_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Node::unsafe_arena_set_allocated_lnode(
    ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_node_type();
  if (value) {
    set_has_lnode();
    _impl_.node_type_.lnode_ = value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:mojo.spec.TreeEnsembleModel.Node.lnode)
}
inline ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NONNULL Node::_internal_mutable_lnode() {
  if (node_type_case() != kLnode) {
    clear_node_type();
    set_has_lnode();
    _impl_.node_type_.lnode_ = 
        ::google::protobuf::Message::DefaultConstruct<::mojo::spec::TreeEnsembleModel::LNode>(GetArena());
  }
  return _impl_.node_type_.lnode_;
}
inline ::mojo::spec::TreeEnsembleModel::LNode* PROTOBUF_NONNULL Node::mutable_lnode()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::mojo::spec::TreeEnsembleModel::LNode* _msg = _internal_mutable_lnode();
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.Node.lnode)
  return _msg;
}

// double data_count = 4;
inline void Node::clear_data_count() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.data_count_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline double Node::data_count() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Node.data_count)
  return _internal_data_count();
}
inline void Node::set_data_count(double value) {
  _internal_set_data_count(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Node.data_count)
}
inline double Node::_internal_data_count() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.data_count_;
}
inline void Node::_internal_set_data_count(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.data_count_ = value;
}

inline bool Node::has_node_type() const {
  return node_type_case() != NODE_TYPE_NOT_SET;
}
inline void Node::clear_has_node_type() {
  _impl_._oneof_case_[0] = NODE_TYPE_NOT_SET;
}
inline Node::NodeTypeCase Node::node_type_case() const {
  return Node::NodeTypeCase(_impl_._oneof_case_[0]);
}
// -------------------------------------------------------------------

// Tree

// repeated .mojo.spec.TreeEnsembleModel.Node nodes = 1;
inline int Tree::_internal_nodes_size() const {
  return _internal_nodes().size();
}
inline int Tree::nodes_size() const {
  return _internal_nodes_size();
}
inline void Tree::clear_nodes() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.nodes_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::mojo::spec::TreeEnsembleModel::Node* PROTOBUF_NONNULL Tree::mutable_nodes(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.Tree.nodes)
  return _internal_mutable_nodes()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>* PROTOBUF_NONNULL Tree::mutable_nodes()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.TreeEnsembleModel.Tree.nodes)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_nodes();
}
inline const ::mojo::spec::TreeEnsembleModel::Node& Tree::nodes(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Tree.nodes)
  return _internal_nodes().Get(index);
}
inline ::mojo::spec::TreeEnsembleModel::Node* PROTOBUF_NONNULL Tree::add_nodes()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::mojo::spec::TreeEnsembleModel::Node* _add =
      _internal_mutable_nodes()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:mojo.spec.TreeEnsembleModel.Tree.nodes)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>& Tree::nodes() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.TreeEnsembleModel.Tree.nodes)
  return _internal_nodes();
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>&
Tree::_internal_nodes() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.nodes_;
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Node>* PROTOBUF_NONNULL
Tree::_internal_mutable_nodes() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.nodes_;
}

// double expected_value = 2;
inline void Tree::clear_expected_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.expected_value_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
inline double Tree::expected_value() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Tree.expected_value)
  return _internal_expected_value();
}
inline void Tree::set_expected_value(double value) {
  _internal_set_expected_value(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Tree.expected_value)
}
inline double Tree::_internal_expected_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.expected_value_;
}
inline void Tree::_internal_set_expected_value(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.expected_value_ = value;
}

// -------------------------------------------------------------------

// Weight

// repeated double weight = 1;
inline int Weight::_internal_weight_size() const {
  return _internal_weight().size();
}
inline int Weight::weight_size() const {
  return _internal_weight_size();
}
inline void Weight::clear_weight() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.weight_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline double Weight::weight(int index) const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Weight.weight)
  return _internal_weight().Get(index);
}
inline void Weight::set_weight(int index, double value) {
  _internal_mutable_weight()->Set(index, value);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Weight.weight)
}
inline void Weight::add_weight(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_weight()->Add(value);
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:mojo.spec.TreeEnsembleModel.Weight.weight)
}
inline const ::google::protobuf::RepeatedField<double>& Weight::weight() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.TreeEnsembleModel.Weight.weight)
  return _internal_weight();
}
inline ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL Weight::mutable_weight()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.TreeEnsembleModel.Weight.weight)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_weight();
}
inline const ::google::protobuf::RepeatedField<double>&
Weight::_internal_weight() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.weight_;
}
inline ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL
Weight::_internal_mutable_weight() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.weight_;
}

// -------------------------------------------------------------------

// TreeBooster

// repeated .mojo.spec.TreeEnsembleModel.Tree trees = 1;
inline int TreeBooster::_internal_trees_size() const {
  return _internal_trees().size();
}
inline int TreeBooster::trees_size() const {
  return _internal_trees_size();
}
inline void TreeBooster::clear_trees() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.trees_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::mojo::spec::TreeEnsembleModel::Tree* PROTOBUF_NONNULL TreeBooster::mutable_trees(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.TreeBooster.trees)
  return _internal_mutable_trees()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>* PROTOBUF_NONNULL TreeBooster::mutable_trees()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.TreeEnsembleModel.TreeBooster.trees)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_trees();
}
inline const ::mojo::spec::TreeEnsembleModel::Tree& TreeBooster::trees(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.TreeBooster.trees)
  return _internal_trees().Get(index);
}
inline ::mojo::spec::TreeEnsembleModel::Tree* PROTOBUF_NONNULL TreeBooster::add_trees()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::mojo::spec::TreeEnsembleModel::Tree* _add =
      _internal_mutable_trees()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:mojo.spec.TreeEnsembleModel.TreeBooster.trees)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>& TreeBooster::trees() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.TreeEnsembleModel.TreeBooster.trees)
  return _internal_trees();
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>&
TreeBooster::_internal_trees() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.trees_;
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Tree>* PROTOBUF_NONNULL
TreeBooster::_internal_mutable_trees() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.trees_;
}

// repeated int32 tree_info = 2;
inline int TreeBooster::_internal_tree_info_size() const {
  return _internal_tree_info().size();
}
inline int TreeBooster::tree_info_size() const {
  return _internal_tree_info_size();
}
inline void TreeBooster::clear_tree_info() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.tree_info_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000002U);
}
inline ::int32_t TreeBooster::tree_info(int index) const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.TreeBooster.tree_info)
  return _internal_tree_info().Get(index);
}
inline void TreeBooster::set_tree_info(int index, ::int32_t value) {
  _internal_mutable_tree_info()->Set(index, value);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.TreeBooster.tree_info)
}
inline void TreeBooster::add_tree_info(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_tree_info()->Add(value);
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add:mojo.spec.TreeEnsembleModel.TreeBooster.tree_info)
}
inline const ::google::protobuf::RepeatedField<::int32_t>& TreeBooster::tree_info() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.TreeEnsembleModel.TreeBooster.tree_info)
  return _internal_tree_info();
}
inline ::google::protobuf::RepeatedField<::int32_t>* PROTOBUF_NONNULL TreeBooster::mutable_tree_info()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.TreeEnsembleModel.TreeBooster.tree_info)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_tree_info();
}
inline const ::google::protobuf::RepeatedField<::int32_t>&
TreeBooster::_internal_tree_info() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.tree_info_;
}
inline ::google::protobuf::RepeatedField<::int32_t>* PROTOBUF_NONNULL
TreeBooster::_internal_mutable_tree_info() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.tree_info_;
}

// -------------------------------------------------------------------

// LinearBooster

// repeated .mojo.spec.TreeEnsembleModel.Weight weights = 1;
inline int LinearBooster::_internal_weights_size() const {
  return _internal_weights().size();
}
inline int LinearBooster::weights_size() const {
  return _internal_weights_size();
}
inline void LinearBooster::clear_weights() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.weights_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::mojo::spec::TreeEnsembleModel::Weight* PROTOBUF_NONNULL LinearBooster::mutable_weights(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.LinearBooster.weights)
  return _internal_mutable_weights()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>* PROTOBUF_NONNULL LinearBooster::mutable_weights()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.TreeEnsembleModel.LinearBooster.weights)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_weights();
}
inline const ::mojo::spec::TreeEnsembleModel::Weight& LinearBooster::weights(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.LinearBooster.weights)
  return _internal_weights().Get(index);
}
inline ::mojo::spec::TreeEnsembleModel::Weight* PROTOBUF_NONNULL LinearBooster::add_weights()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::mojo::spec::TreeEnsembleModel::Weight* _add =
      _internal_mutable_weights()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:mojo.spec.TreeEnsembleModel.LinearBooster.weights)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>& LinearBooster::weights() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.TreeEnsembleModel.LinearBooster.weights)
  return _internal_weights();
}
inline const ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>&
LinearBooster::_internal_weights() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.weights_;
}
inline ::google::protobuf::RepeatedPtrField<::mojo::spec::TreeEnsembleModel::Weight>* PROTOBUF_NONNULL
LinearBooster::_internal_mutable_weights() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.weights_;
}

// repeated double bias = 2;
inline int LinearBooster::_internal_bias_size() const {
  return _internal_bias().size();
}
inline int LinearBooster::bias_size() const {
  return _internal_bias_size();
}
inline void LinearBooster::clear_bias() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.bias_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000002U);
}
inline double LinearBooster::bias(int index) const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.LinearBooster.bias)
  return _internal_bias().Get(index);
}
inline void LinearBooster::set_bias(int index, double value) {
  _internal_mutable_bias()->Set(index, value);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.LinearBooster.bias)
}
inline void LinearBooster::add_bias(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_bias()->Add(value);
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add:mojo.spec.TreeEnsembleModel.LinearBooster.bias)
}
inline const ::google::protobuf::RepeatedField<double>& LinearBooster::bias() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:mojo.spec.TreeEnsembleModel.LinearBooster.bias)
  return _internal_bias();
}
inline ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL LinearBooster::mutable_bias()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_mutable_list:mojo.spec.TreeEnsembleModel.LinearBooster.bias)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_bias();
}
inline const ::google::protobuf::RepeatedField<double>&
LinearBooster::_internal_bias() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.bias_;
}
inline ::google::protobuf::RepeatedField<double>* PROTOBUF_NONNULL
LinearBooster::_internal_mutable_bias() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.bias_;
}

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// Model

// string version = 1;
inline void Model::clear_version() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.version_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline const ::std::string& Model::version() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Model.version)
  return _internal_version();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void Model::set_version(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.version_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Model.version)
}
inline ::std::string* PROTOBUF_NONNULL Model::mutable_version()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_version();
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.Model.version)
  return _s;
}
inline const ::std::string& Model::_internal_version() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.version_.Get();
}
inline void Model::_internal_set_version(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.version_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL Model::_internal_mutable_version() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.version_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE Model::release_version() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:mojo.spec.TreeEnsembleModel.Model.version)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.version_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.version_.Set("", GetArena());
  }
  return released;
}
inline void Model::set_allocated_version(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.version_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.version_.IsDefault()) {
    _impl_.version_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:mojo.spec.TreeEnsembleModel.Model.version)
}

// int32 num_output_group = 2;
inline void Model::clear_num_output_group() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.num_output_group_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
inline ::int32_t Model::num_output_group() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Model.num_output_group)
  return _internal_num_output_group();
}
inline void Model::set_num_output_group(::int32_t value) {
  _internal_set_num_output_group(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Model.num_output_group)
}
inline ::int32_t Model::_internal_num_output_group() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.num_output_group_;
}
inline void Model::_internal_set_num_output_group(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.num_output_group_ = value;
}

// double base_margin = 3;
inline void Model::clear_base_margin() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.base_margin_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000002U);
}
inline double Model::base_margin() const {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Model.base_margin)
  return _internal_base_margin();
}
inline void Model::set_base_margin(double value) {
  _internal_set_base_margin(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_set:mojo.spec.TreeEnsembleModel.Model.base_margin)
}
inline double Model::_internal_base_margin() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.base_margin_;
}
inline void Model::_internal_set_base_margin(double value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.base_margin_ = value;
}

// .mojo.spec.TreeEnsembleModel.TreeBooster tree = 4;
inline bool Model::has_tree() const {
  return booster_case() == kTree;
}
inline bool Model::_internal_has_tree() const {
  return booster_case() == kTree;
}
inline void Model::set_has_tree() {
  _impl_._oneof_case_[0] = kTree;
}
inline void Model::clear_tree() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (booster_case() == kTree) {
    if (GetArena() == nullptr) {
      delete _impl_.booster_.tree_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.booster_.tree_);
    }
    clear_has_booster();
  }
}
inline ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE Model::release_tree() {
  // @@protoc_insertion_point(field_release:mojo.spec.TreeEnsembleModel.Model.tree)
  if (booster_case() == kTree) {
    clear_has_booster();
    auto* temp = _impl_.booster_.tree_;
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.booster_.tree_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::mojo::spec::TreeEnsembleModel::TreeBooster& Model::_internal_tree() const {
  return booster_case() == kTree ? static_cast<const ::mojo::spec::TreeEnsembleModel::TreeBooster&>(*_impl_.booster_.tree_)
                     : reinterpret_cast<const ::mojo::spec::TreeEnsembleModel::TreeBooster&>(::mojo::spec::TreeEnsembleModel::_TreeBooster_default_instance_);
}
inline const ::mojo::spec::TreeEnsembleModel::TreeBooster& Model::tree() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Model.tree)
  return _internal_tree();
}
inline ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE Model::unsafe_arena_release_tree() {
  // @@protoc_insertion_point(field_unsafe_arena_release:mojo.spec.TreeEnsembleModel.Model.tree)
  if (booster_case() == kTree) {
    clear_has_booster();
    auto* temp = _impl_.booster_.tree_;
    _impl_.booster_.tree_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Model::unsafe_arena_set_allocated_tree(
    ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_booster();
  if (value) {
    set_has_tree();
    _impl_.booster_.tree_ = value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:mojo.spec.TreeEnsembleModel.Model.tree)
}
inline ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NONNULL Model::_internal_mutable_tree() {
  if (booster_case() != kTree) {
    clear_booster();
    set_has_tree();
    _impl_.booster_.tree_ = 
        ::google::protobuf::Message::DefaultConstruct<::mojo::spec::TreeEnsembleModel::TreeBooster>(GetArena());
  }
  return _impl_.booster_.tree_;
}
inline ::mojo::spec::TreeEnsembleModel::TreeBooster* PROTOBUF_NONNULL Model::mutable_tree()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::mojo::spec::TreeEnsembleModel::TreeBooster* _msg = _internal_mutable_tree();
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.Model.tree)
  return _msg;
}

// .mojo.spec.TreeEnsembleModel.LinearBooster linear = 5;
inline bool Model::has_linear() const {
  return booster_case() == kLinear;
}
inline bool Model::_internal_has_linear() const {
  return booster_case() == kLinear;
}
inline void Model::set_has_linear() {
  _impl_._oneof_case_[0] = kLinear;
}
inline void Model::clear_linear() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (booster_case() == kLinear) {
    if (GetArena() == nullptr) {
      delete _impl_.booster_.linear_;
    } else if (::google::protobuf::internal::DebugHardenClearOneofMessageOnArena()) {
      ::google::protobuf::internal::MaybePoisonAfterClear(_impl_.booster_.linear_);
    }
    clear_has_booster();
  }
}
inline ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE Model::release_linear() {
  // @@protoc_insertion_point(field_release:mojo.spec.TreeEnsembleModel.Model.linear)
  if (booster_case() == kLinear) {
    clear_has_booster();
    auto* temp = _impl_.booster_.linear_;
    if (GetArena() != nullptr) {
      temp = ::google::protobuf::internal::DuplicateIfNonNull(temp);
    }
    _impl_.booster_.linear_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::mojo::spec::TreeEnsembleModel::LinearBooster& Model::_internal_linear() const {
  return booster_case() == kLinear ? static_cast<const ::mojo::spec::TreeEnsembleModel::LinearBooster&>(*_impl_.booster_.linear_)
                     : reinterpret_cast<const ::mojo::spec::TreeEnsembleModel::LinearBooster&>(::mojo::spec::TreeEnsembleModel::_LinearBooster_default_instance_);
}
inline const ::mojo::spec::TreeEnsembleModel::LinearBooster& Model::linear() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:mojo.spec.TreeEnsembleModel.Model.linear)
  return _internal_linear();
}
inline ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE Model::unsafe_arena_release_linear() {
  // @@protoc_insertion_point(field_unsafe_arena_release:mojo.spec.TreeEnsembleModel.Model.linear)
  if (booster_case() == kLinear) {
    clear_has_booster();
    auto* temp = _impl_.booster_.linear_;
    _impl_.booster_.linear_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void Model::unsafe_arena_set_allocated_linear(
    ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NULLABLE value) {
  // We rely on the oneof clear method to free the earlier contents
  // of this oneof. We can directly use the pointer we're given to
  // set the new value.
  clear_booster();
  if (value) {
    set_has_linear();
    _impl_.booster_.linear_ = value;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:mojo.spec.TreeEnsembleModel.Model.linear)
}
inline ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NONNULL Model::_internal_mutable_linear() {
  if (booster_case() != kLinear) {
    clear_booster();
    set_has_linear();
    _impl_.booster_.linear_ = 
        ::google::protobuf::Message::DefaultConstruct<::mojo::spec::TreeEnsembleModel::LinearBooster>(GetArena());
  }
  return _impl_.booster_.linear_;
}
inline ::mojo::spec::TreeEnsembleModel::LinearBooster* PROTOBUF_NONNULL Model::mutable_linear()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::mojo::spec::TreeEnsembleModel::LinearBooster* _msg = _internal_mutable_linear();
  // @@protoc_insertion_point(field_mutable:mojo.spec.TreeEnsembleModel.Model.linear)
  return _msg;
}

// map<int32, string> feature_map = 6;
inline int Model::_internal_feature_map_size() const {
  return _internal_feature_map().size();
}
inline int Model::feature_map_size() const {
  return _internal_feature_map_size();
}
inline void Model::clear_feature_map() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.feature_map_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000008U);
}
inline const ::google::protobuf::Map<::int32_t, ::std::string>& Model::_internal_feature_map() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.feature_map_.GetMap();
}
inline const ::google::protobuf::Map<::int32_t, ::std::string>& Model::feature_map() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_map:mojo.spec.TreeEnsembleModel.Model.feature_map)
  return _internal_feature_map();
}
inline ::google::protobuf::Map<::int32_t, ::std::string>* PROTOBUF_NONNULL Model::_internal_mutable_feature_map() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.feature_map_.MutableMap();
}
inline ::google::protobuf::Map<::int32_t, ::std::string>* PROTOBUF_NONNULL Model::mutable_feature_map()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_mutable_map:mojo.spec.TreeEnsembleModel.Model.feature_map)
  return _internal_mutable_feature_map();
}

inline bool Model::has_booster() const {
  return booster_case() != BOOSTER_NOT_SET;
}
inline void Model::clear_has_booster() {
  _impl_._oneof_case_[0] = BOOSTER_NOT_SET;
}
inline Model::BoosterCase Model::booster_case() const {
  return Model::BoosterCase(_impl_._oneof_case_[0]);
}
#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace TreeEnsembleModel
}  // namespace spec
}  // namespace mojo


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::mojo::spec::TreeEnsembleModel::INode_MissingType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::mojo::spec::TreeEnsembleModel::INode_MissingType>() {
  return ::mojo::spec::TreeEnsembleModel::INode_MissingType_descriptor();
}
template <>
struct is_proto_enum<::mojo::spec::TreeEnsembleModel::SplitType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::mojo::spec::TreeEnsembleModel::SplitType>() {
  return ::mojo::spec::TreeEnsembleModel::SplitType_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"

#endif  // Tree_2eproto_2epb_2eh
